@@ -11,7 +11,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "8.66.2"
+__version__ = "8.69.0"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -179,6 +179,9 @@ elif board_id == ap_board.BANANA_PI_AI2H:
 elif board_id == ap_board.BANANA_PI_F5:
     from adafruit_blinka.board.bananapi.bpif5 import *
 
+elif board_id == ap_board.BANANA_PI_P2_PRO:
+    from adafruit_blinka.board.bananapi.bpip2pro import *
+
 elif board_id == ap_board.LEMAKER_BANANA_PRO:
     from adafruit_blinka.board.lemaker.bananapro import *
 
@@ -464,6 +467,9 @@ elif board_id == ap_board.LUCKFOX_PICO_PLUS:
 elif board_id == ap_board.LUCKFOX_PICO_MAX:
     from adafruit_blinka.board.luckfox.luckfoxpico_max import *
 
+elif board_id == ap_board.LUCKFOX_PICO_ULTRA:
+    from adafruit_blinka.board.luckfox.luckfoxpico_ultra import *
+
 elif board_id == ap_board.VIVID_UNIT:
     from adafruit_blinka.board.vivid_unit import *
 
